SPAMS: a SPArse Modeling Software, v2.6
Author: Julien Mairal

# SPAMS: a SPArse Modeling Software, v2.6 ### Julien Mairal julien.mairal@m4x.org Python and R interfaces by Jean-Paul Chieze Archetypal Analysis by Yuansi Chen Porting to R-3.x/Python-3.x by Ghislain Durif and the output of numerous collaborations with Rodolphe Jenatton, Francis Bach, Jean Ponce, Guillaume Obozinski, Bin Yu, Guillermo Sapiro, and Zaid Harchaoui.

- Contents
- Introduction
- Installation
- Dictionary Learning and Matrix Factorization Toolbox
  - Function spams.trainDL
  - Function spams.trainDL_Memory
  - Function spams.structTrainDL
  - Function nmf
  - Function nnsc
  - Function spams.archetypalAnalysis
- Sparse Decomposition Toolbox
  - Function spams.omp
  - Function spams.ompMask
  - Function mexRidgeRegression
  - Function spams.lasso
  - Function spams.lassoWeighted
  - Function spams.lassoMask
  - Function spams.cd
  - Function spams.somp
  - Function spams.l1L2BCD
  - Function spams.sparseProject
  - Function spams.decompSimplex
- Proximal Toolbox
  - Regularization Functions
  - Function spams.proximalFlat
  - Function spams.proximalTree
  - Function spams.proximalGraph
  - Function spams.proximalPathCoding
  - Function spams.evalPathCoding
  - Problems Addressed
  - Function spams.fistaFlat
  - Function spams.fistaTree
  - Function spams.fistaGraph
  - Function spams.fistaPathCoding
  - Function solverPoisson
  - Function mexIncrementalProx
  - Function mexStochasticProx
- A few Functions for manipulating images
  - Function mexExtractPatches
  - Function mexCombinePatches
  - Function mexConvFistaFlat
- Miscellaneous Functions
  - Function spams.conjGrad
  - Function spams.bayer
  - Function spams.calcAAt
  - Function spams.calcXAt
  - Function spams.calcXY
  - Function spams.calcXYt
  - Function spams.calcXtY
  - Function spams.invSym
  - Function spams.normalize
  - Function spams.sort
  - Function displayPatches
  - Function spams.countPathsDAG
  - Function spams.removeCyclesGraph
  - Function spams.countConnexComponents
  - Function spams.graphOfGroupStruct
  - Function spams.groupStructOfString
  - Function spams.readGroupStruct
  - Function spams.treeOfGroupStruct
  - Function spams.simpleGroupTree
- Duality Gaps with Fenchel Duality
- References

> This document was translated from LATEX by HEVEA.